@@ -3,7 +3,7 @@ from urllib.parse import urlparse, urlunparse, ParseResult
 
 from django.core.exceptions import ValidationError
 from django.forms import widgets
-from django.forms.fields import BooleanField, ChoiceField, URLField, Field
+from django.forms.fields import BooleanField, ChoiceField, URLField
 from django.utils.translation import gettext_lazy as _
 from entangled.forms import EntangledModelFormMixin, EntangledField
 from cms.plugin_pool import plugin_pool
@@ -56,6 +56,7 @@ class YoutubeFormMixin(EntangledModelFormMixin):
     rel = BooleanField(
         label=_("Show related"),
         required=False,
+        help_text=_("Show videos suggested by YouTube at the end."),
     )
 
     class Meta:
