@@ -1,7 +1,7 @@
 from django.utils.safestring import mark_safe
 from cmsplugin_cascade.models import IconFont
 from cmsplugin_cascade.plugin_base import CascadePluginMixinBase
-from entangled.forms import get_related_object
+from entangled.utils import get_related_object
 
 
 class IconPluginMixin(CascadePluginMixinBase):
