@@ -8,6 +8,8 @@ from cmsplugin_cascade import app_settings
 @toolbar_pool.register
 class SegmentationToolbar(CMSToolbar):
     def populate(self):
+        if not self.request.user.has_perm('cmsplugin_cascade.view_segmentation'):
+            return
         menu = self.toolbar.get_or_create_menu('segmentation', _("Segmentation"))
         for sgm in app_settings.CMSPLUGIN_CASCADE['segmentation_mixins']:
             SegmentationMixin = import_string(sgm[1])
